******************************************
* Title : Vector Graphics Routines (VGR) *
* By    : Kenneth Bernholm		 *
******************************************

***** Memory reservations *****

Screen0   = $60000
Screen1   = Screen0+8000
ProgStart = Screen1+8000

org  ProgStart
load ProgStart

Start:
bsr    Init_Interrupts
bsr    Init_Screen

Test_Left_Button:
btst   #6,$bfe001
bne    Test_Left_Button
bsr    Restore_Screen
bsr    Restore_Interrupts
clr.l  d0
rts

************************
***** Sub Programs *****
************************

***** Interrup routines *****

Init_Interrupts:
move.w $dff01e,Sys_Intreq
move.w $dff01c,Sys_Intena
move.w #$7fff,$dff09c
move.w #$7fff,$dff09a
move.l $6c,Sys_Level3
move.l #My_Level3,$6c
move.w #$8020,$dff09a
move.w #$c000,$dff09a
rts

Restore_Interrupts:
move.l Sys_Level3,$6c
or.w   #$8000,Sys_Intena
or.w   #$8000,Sys_Intreq
move.w Sys_Intreq,$dff09c
move.w Sys_Intena,$dff09a
rts

***** Screen Routines *****

Init_Screen:
move.l 4,a6
move.l 156(a6),a1
move.l 38(a1),Sys_Copper
move.l a7,Sys_Stack
move.l #Copper_List,$dff080
move.w #$0020,$dff096
rts

Restore_Screen:
move.l 4,a6
move.l Sys_Copper,$dff080
move.l Sys_Stack,a7
move.w #$8020,$dff096
rts

Flip_Screen:
cmp.l  #Screen1,Screen_Address
beq    Flip_To_Screen1
Flip_To_Screen0:
lea    Bpl_Pointers,a0
move.l #Screen0,d0
move.w d0,6(a0)
swap   d0
move.w d0,2(a0)
move.l #Screen1,Screen_Address
bra    Flip_Screen_exit
Flip_To_Screen1:
lea    Bpl_Pointers,a0
move.l #Screen1,d0
move.w d0,6(a0)
swap   d0
move.w d0,2(a0)
move.l #Screen0,Screen_Address
Flip_Screen_Exit:
rts

***** Level 3 Interrupt *****

My_Level3:
btst   #5,$dff01f
beq    My_Level3_Exit
bsr    Draw_Figure
move.w #$0800,$dff180
bsr    Flip_Screen
move.w #$0020,$dff09c
My_Level3_Exit:
rte

***** Vector Routines *****

Draw_Figure:
btst   #14,$dff002
bne    Draw_Figure
move.l #$01000000,$dff040
move.l Screen_Address,$dff054
move.w #$0,$dff066
move.w #[200*64]+20,$dff058
move.l #$00008000,$dff072
move.l #$ffffffff,$dff044
move.w #40,$dff060

move.l xdelta,d0
add.l  d0,xgrad
and.l  #$000001ff,xgrad
move.l ygrad,d6
add.l  ydelta,d6
and.l  #$000001ff,d6
move.l d6,ygrad
lsl.w  #1,d6
move.l zgrad,d7
add.l  zdelta,d7
and.l  #$000001ff,d7
move.l d7,zgrad
lsl.w  #1,d7

move.l Screen_Address,a0
lea    Figure1,a1
lea    Sin_Table,a2
lea    Cos_Table,a3
lea    Octant_Table,a4
Draw_Figure2:
cmp.w  #555,(a1)
beq    Draw_Figure_exit
move.l xgrad,d5
lsl.w  #1,d5

move.w (a3,d5),d0
muls   4(a1),d0
move.w (a2,d5),d1
muls   6(a1),d1
sub.l  d1,d0
lsl.l  #2,d0
move.l d0,y1
move.w (a2,d5),d0
muls   4(a1),d0
move.w (a3,d5),d1
muls   6(a1),d1
add.l  d1,d0
lsl.l  #2,d0
move.l d0,z1

move.w (a3,d6),d0
muls   2(a1),d0
move.w (a2,d6),d1
muls   z1,d1
sub.l  d1,d0
lsl.l  #2,d0
move.l d0,x2
move.w (a2,d6),d0
muls   2(a1),d0
move.w (a3,d6),d1
muls   z1,d1
add.l  d1,d0
lsl.l  #2,d0
swap   d0
ext.l  d0
move.l d0,z2

move.w (a3,d7),d0
muls   x2,d0
move.w (a2,d7),d1
muls   y1,d1
sub.l  d1,d0
lsl.l  #2,d0
swap   d0
ext.l  d0
move.w (a2,d7),d1
muls   x2,d1
move.w (a3,d7),d2
muls   y1,d2
add.l  d2,d1
lsl.l  #2,d1
swap   d1
ext.l  d1

move.l yviewpoint,d2
muls   d0,d2
move.l viewdistance,d4
add.l  d1,d4
divs   d4,d2
ext.l  d2
add.l  xorigo,d2
move.l last_x_point,d0
move.l d2,last_x_point
move.l d1,d3
add.l  yorigo,d3
move.l zviewpoint,d4
sub.l  z2,d4
muls   d3,d4
add.l  viewdistance,d1
divs   d1,d4
ext.l  d4
add.l  z2,d4
lsr.l  #1,d4
move.l zorigo,d3
sub.l  d4,d3
move.l last_y_point,d1
move.l d3,last_y_point

tst.w  (a1)
beq    Draw_Figure3
cmp.l  d0,d2
bne    Draw1
cmp.l  d1,d3
bne    Draw1
bra    Draw_Figure3

Draw1:
move.l d1,d4
move.l d4,d5
lsl.w  #5,d4
lsl.w  #3,d5
add.l  d5,d4
move.l d0,d5
lsr.w  #3,d5
add.l  d5,d4
add.l  a0,d4

move.l #0,d5
sub.w  d1,d3
roxl.b #1,d5
tst.w  d3
bge    y2gy1
neg.w  d3
y2gy1:
sub.w  d0,d2
roxl.b #1,d5
tst.w  d2
bge    x2gx1
neg.w  d2
x2gx1:
move.w d3,d1
sub.w  d2,d1
bge    dygdx
exg    d2,d3
dygdx:
roxl.b #1,d5
move.b (a4,d5),d5
lsl.l  #1,d2
and.w  #$000f,d0
ror.w  #4,d0
or.w   #$0bfa,d0
move.l d3,d1
lsl.w  #6,d3
addq.w #2,d3
draw99:
btst   #14,$dff002
bne    draw99
move.w d2,$dff062
sub.w  d1,d2
bge    signnl
or.b   #$40,d5
signnl:
move.w d2,$dff052
sub.w  d1,d2
move.w d2,$dff064
move.w d0,$dff040
move.w d5,$dff042
move.l d4,$dff048
move.l d4,$dff054
move.w #40,$dff066
move.w d3,$dff058
Draw_Figure3:
addq.l #8,a1
bra    Draw_Figure2
Draw_Figure_Exit:
rts

***** DATA !!! *****

even
Sys_Intreq:
dc.w 0
Sys_Intena:
dc.w 0
Sys_Level3:
dc.l 0
Sys_Copper:
dc.l 0
Sys_Stack:
dc.l 0
Screen_Address:
dc.l Screen0
Octant_Table:
dc.b %00000001,%00010001,%00001001,%00010101
dc.b %00000101,%00011001,%00001101,%00011101
xorigo:
dc.l 160
yorigo:
dc.l -100
zorigo:
dc.l 100
yviewpoint:
dc.l 250
zviewpoint:
dc.l 0
viewdistance:
dc.l 300
xgrad:
dc.l 0
ygrad:
dc.l 0
zgrad:
dc.l 0
xdelta:
dc.l 5
ydelta:
dc.l 3
zdelta:
dc.l 1
y1:
dc.l 0
z1:
dc.l 0
x2:
dc.l 0
z2:
dc.l 0
last_x_point:
dc.l 0
last_y_point:
dc.l 0

figure1:
dc.w 0,65,0,-65,1,65,0,65,1,65,0,-80,1,-57,0,-80,1,-65,0,-72,1,-65,0,65,0,-53,0,65
dc.w 1,-53,0,-20,1,53,0,-20,1,53,0,65,0,55,0,55,1,61,0,55,1,61,0,49,1,55,0,49
dc.w 1,55,0,55,0,-34,0,-80,1,-34,0,-34,1,53,0,-34,1,53,0,-80,1,32,0,-80,1,32,0,-34
dc.w 0,-24,0,-73,1,-24,0,-37,1,-8,0,-73,1,-24,0,-73,0,-40,0,30,1,-15,0,0
dc.w 1,25,0,55,0,-30,0,30,1,-5,0,0,1,35,0,55,0,-20,0,30,1,5,0,0,1,45,0,55,0,-65,50,65
dc.w 1,65,50,65,1,65,50,-80,1,-57,50,-80,1,-65,50,-72,1,-65,50,65,0,-53,50,65
dc.w 1,-53,50,-20,1,-53,50,-20,1,-53,50,65,0,55,50,55,1,61,50,55,1,61,50,49,1,55,50,49
dc.w 1,55,50,55,0,-34,50,-80,1,-34,50,-34,1,53,50,-34,1,53,50,-80,1,32,50,-80
dc.w 1,32,50,-34,555,555,555,555

Copper_List:
dc.w $0100,$1200,$0104,$0024,$0102,$0000,$0108,$0000
dc.w $010a,$0000,$008e,$2c81,$0090,$f4c1,$0092,$0038
dc.w $0094,$00d0
Bpl_Pointers:
dc.w $00e0,$0000,$00e2,$0000
dc.w $0180,$0000,$0182,$00f0
dc.w $ffff,$fffe

Sin_Table:
	dc.w	           0 
	dc.w	           201 
	dc.w	           402 
	dc.w	           603 
	dc.w	           803 
	dc.w	           1004 
	dc.w	           1205 
	dc.w	           1405 
	dc.w	           1605 
	dc.w	           1805 
	dc.w	           2005 
	dc.w	           2204 
	dc.w	           2404 
	dc.w	           2602 
	dc.w	           2801 
	dc.w	           2998 
	dc.w	           3196 
	dc.w	           3393 
	dc.w	           3589 
	dc.w	           3785 
	dc.w	           3980 
	dc.w	           4175 
	dc.w	           4369 
	dc.w	           4563 
	dc.w	           4756 
	dc.w	           4948 
	dc.w	           5139 
	dc.w	           5329 
	dc.w	           5519 
	dc.w	           5708 
	dc.w	           5896 
	dc.w	           6083 
	dc.w	           6269 
	dc.w	           6455 
	dc.w	           6639 
	dc.w	           6822 
	dc.w	           7005 
	dc.w	           7186 
	dc.w	           7366 
	dc.w	           7545 
	dc.w	           7723 
	dc.w	           7900 
	dc.w	           8075 
	dc.w	           8249 
	dc.w	           8423 
	dc.w	           8594 
	dc.w	           8765 
	dc.w	           8934 
	dc.w	           9102 
	dc.w	           9268 
	dc.w	           9434 
	dc.w	           9597 
	dc.w	           9759 
	dc.w	           9920 
	dc.w	           10079 
	dc.w	           10237 
	dc.w	           10393 
	dc.w	           10548 
	dc.w	           10701 
	dc.w	           10853 
	dc.w	           11002 
	dc.w	           11150 
	dc.w	           11297 
	dc.w	           11442 
	dc.w	           11585 
	dc.w	           11726 
	dc.w	           11866 
	dc.w	           12003 
	dc.w	           12139 
	dc.w	           12273 
	dc.w	           12406 
	dc.w	           12536 
	dc.w	           12665 
	dc.w	           12791 
	dc.w	           12916 
	dc.w	           13038 
	dc.w	           13159 
	dc.w	           13278 
	dc.w	           13395 
	dc.w	           13510 
	dc.w	           13622 
	dc.w	           13733 
	dc.w	           13842 
	dc.w	           13948 
	dc.w	           14053 
	dc.w	           14155 
	dc.w	           14255 
	dc.w	           14353 
	dc.w	           14449 
	dc.w	           14543 
	dc.w	           14634 
	dc.w	           14723 
	dc.w	           14810 
	dc.w	           14895 
	dc.w	           14978 
	dc.w	           15058 
	dc.w	           15136 
	dc.w	           15212 
	dc.w	           15286 
	dc.w	           15357 
	dc.w	           15426 
	dc.w	           15492 
	dc.w	           15557 
	dc.w	           15618 
	dc.w	           15678 
	dc.w	           15735 
	dc.w	           15790 
	dc.w	           15842 
	dc.w	           15892 
	dc.w	           15940 
	dc.w	           15985 
	dc.w	           16028 
	dc.w	           16069 
	dc.w	           16107 
	dc.w	           16142 
	dc.w	           16175 
	dc.w	           16206 
	dc.w	           16234 
	dc.w	           16260 
	dc.w	           16284 
	dc.w	           16305 
	dc.w	           16323 
	dc.w	           16339 
	dc.w	           16353 
	dc.w	           16364 
	dc.w	           16372 
	dc.w	           16379 
	dc.w	           16382 
	dc.w	           16384 
	dc.w	           16382 
	dc.w	           16379 
	dc.w	           16372 
	dc.w	           16364 
	dc.w	           16353 
	dc.w	           16339 
	dc.w	           16323 
	dc.w	           16305 
	dc.w	           16284 
	dc.w	           16260 
	dc.w	           16234 
	dc.w	           16206 
	dc.w	           16175 
	dc.w	           16142 
	dc.w	           16107 
	dc.w	           16069 
	dc.w	           16028 
	dc.w	           15985 
	dc.w	           15940 
	dc.w	           15892 
	dc.w	           15842 
	dc.w	           15790 
	dc.w	           15735 
	dc.w	           15678 
	dc.w	           15618 
	dc.w	           15557 
	dc.w	           15492 
	dc.w	           15426 
	dc.w	           15357 
	dc.w	           15286 
	dc.w	           15212 
	dc.w	           15136 
	dc.w	           15058 
	dc.w	           14978 
	dc.w	           14895 
	dc.w	           14810 
	dc.w	           14723 
	dc.w	           14634 
	dc.w	           14543 
	dc.w	           14449 
	dc.w	           14353 
	dc.w	           14255 
	dc.w	           14155 
	dc.w	           14053 
	dc.w	           13948 
	dc.w	           13842 
	dc.w	           13733 
	dc.w	           13622 
	dc.w	           13510 
	dc.w	           13395 
	dc.w	           13278 
	dc.w	           13159 
	dc.w	           13038 
	dc.w	           12916 
	dc.w	           12791 
	dc.w	           12665 
	dc.w	           12536 
	dc.w	           12406 
	dc.w	           12273 
	dc.w	           12139 
	dc.w	           12003 
	dc.w	           11866 
	dc.w	           11726 
	dc.w	           11585 
	dc.w	           11442 
	dc.w	           11297 
	dc.w	           11150 
	dc.w	           11002 
	dc.w	           10853 
	dc.w	           10701 
	dc.w	           10548 
	dc.w	           10393 
	dc.w	           10237 
	dc.w	           10079 
	dc.w	           9920 
	dc.w	           9759 
	dc.w	           9597 
	dc.w	           9434 
	dc.w	           9268 
	dc.w	           9102 
	dc.w	           8934 
	dc.w	           8765 
	dc.w	           8594 
	dc.w	           8423 
	dc.w	           8249 
	dc.w	           8075 
	dc.w	           7900 
	dc.w	           7723 
	dc.w	           7545 
	dc.w	           7366 
	dc.w	           7186 
	dc.w	           7005 
	dc.w	           6822 
	dc.w	           6639 
	dc.w	           6455 
	dc.w	           6269 
	dc.w	           6083 
	dc.w	           5896 
	dc.w	           5708 
	dc.w	           5519 
	dc.w	           5329 
	dc.w	           5139 
	dc.w	           4948 
	dc.w	           4756 
	dc.w	           4563 
	dc.w	           4369 
	dc.w	           4175 
	dc.w	           3980 
	dc.w	           3785 
	dc.w	           3589 
	dc.w	           3393 
	dc.w	           3196 
	dc.w	           2998 
	dc.w	           2801 
	dc.w	           2602 
	dc.w	           2404 
	dc.w	           2204 
	dc.w	           2005 
	dc.w	           1805 
	dc.w	           1605 
	dc.w	           1405 
	dc.w	           1205 
	dc.w	           1004 
	dc.w	           803 
	dc.w	           603 
	dc.w	           402 
	dc.w	           201 
	dc.w	          -1 
	dc.w	          -202 
	dc.w	          -403 
	dc.w	          -604 
	dc.w	          -804 
	dc.w	          -1005 
	dc.w	          -1206 
	dc.w	          -1406 
	dc.w	          -1606 
	dc.w	          -1806 
	dc.w	          -2006 
	dc.w	          -2205 
	dc.w	          -2405 
	dc.w	          -2603 
	dc.w	          -2802 
	dc.w	          -2999 
	dc.w	          -3197 
	dc.w	          -3394 
	dc.w	          -3590 
	dc.w	          -3786 
	dc.w	          -3981 
	dc.w	          -4176 
	dc.w	          -4370 
	dc.w	          -4564 
	dc.w	          -4757 
	dc.w	          -4949 
	dc.w	          -5140 
	dc.w	          -5330 
	dc.w	          -5520 
	dc.w	          -5709 
	dc.w	          -5897 
	dc.w	          -6084 
	dc.w	          -6270 
	dc.w	          -6456 
	dc.w	          -6640 
	dc.w	          -6823 
	dc.w	          -7006 
	dc.w	          -7187 
	dc.w	          -7367 
	dc.w	          -7546 
	dc.w	          -7724 
	dc.w	          -7901 
	dc.w	          -8076 
	dc.w	          -8250 
	dc.w	          -8424 
	dc.w	          -8595 
	dc.w	          -8766 
	dc.w	          -8935 
	dc.w	          -9103 
	dc.w	          -9269 
	dc.w	          -9435 
	dc.w	          -9598 
	dc.w	          -9760 
	dc.w	          -9921 
	dc.w	          -10080 
	dc.w	          -10238 
	dc.w	          -10394 
	dc.w	          -10549 
	dc.w	          -10702 
	dc.w	          -10854 
	dc.w	          -11003 
	dc.w	          -11151 
	dc.w	          -11298 
	dc.w	          -11443 
	dc.w	          -11586 
	dc.w	          -11727 
	dc.w	          -11867 
	dc.w	          -12004 
	dc.w	          -12140 
	dc.w	          -12274 
	dc.w	          -12407 
	dc.w	          -12537 
	dc.w	          -12666 
	dc.w	          -12792 
	dc.w	          -12917 
	dc.w	          -13039 
	dc.w	          -13160 
	dc.w	          -13279 
	dc.w	          -13396 
	dc.w	          -13511 
	dc.w	          -13623 
	dc.w	          -13734 
	dc.w	          -13843 
	dc.w	          -13949 
	dc.w	          -14054 
	dc.w	          -14156 
	dc.w	          -14256 
	dc.w	          -14354 
	dc.w	          -14450 
	dc.w	          -14544 
	dc.w	          -14635 
	dc.w	          -14724 
	dc.w	          -14811 
	dc.w	          -14896 
	dc.w	          -14979 
	dc.w	          -15059 
	dc.w	          -15137 
	dc.w	          -15213 
	dc.w	          -15287 
	dc.w	          -15358 
	dc.w	          -15427 
	dc.w	          -15493 
	dc.w	          -15558 
	dc.w	          -15619 
	dc.w	          -15679 
	dc.w	          -15736 
	dc.w	          -15791 
	dc.w	          -15843 
	dc.w	          -15893 
	dc.w	          -15941 
	dc.w	          -15986 
	dc.w	          -16029 
	dc.w	          -16070 
	dc.w	          -16108 
	dc.w	          -16143 
	dc.w	          -16176 
	dc.w	          -16207 
	dc.w	          -16235 
	dc.w	          -16261 
	dc.w	          -16285 
	dc.w	          -16306 
	dc.w	          -16324 
	dc.w	          -16340 
	dc.w	          -16354 
	dc.w	          -16365 
	dc.w	          -16373 
	dc.w	          -16380 
	dc.w	          -16383 
	dc.w	          -16384 
	dc.w	          -16383 
	dc.w	          -16380 
	dc.w	          -16373 
	dc.w	          -16365 
	dc.w	          -16354 
	dc.w	          -16340 
	dc.w	          -16324 
	dc.w	          -16306 
	dc.w	          -16285 
	dc.w	          -16261 
	dc.w	          -16235 
	dc.w	          -16207 
	dc.w	          -16176 
	dc.w	          -16143 
	dc.w	          -16108 
	dc.w	          -16070 
	dc.w	          -16029 
	dc.w	          -15986 
	dc.w	          -15941 
	dc.w	          -15893 
	dc.w	          -15843 
	dc.w	          -15791 
	dc.w	          -15736 
	dc.w	          -15679 
	dc.w	          -15619 
	dc.w	          -15558 
	dc.w	          -15493 
	dc.w	          -15427 
	dc.w	          -15358 
	dc.w	          -15287 
	dc.w	          -15213 
	dc.w	          -15137 
	dc.w	          -15059 
	dc.w	          -14979 
	dc.w	          -14896 
	dc.w	          -14811 
	dc.w	          -14724 
	dc.w	          -14635 
	dc.w	          -14544 
	dc.w	          -14450 
	dc.w	          -14354 
	dc.w	          -14256 
	dc.w	          -14156 
	dc.w	          -14054 
	dc.w	          -13949 
	dc.w	          -13843 
	dc.w	          -13734 
	dc.w	          -13623 
	dc.w	          -13511 
	dc.w	          -13396 
	dc.w	          -13279 
	dc.w	          -13160 
	dc.w	          -13039 
	dc.w	          -12917 
	dc.w	          -12792 
	dc.w	          -12666 
	dc.w	          -12537 
	dc.w	          -12407 
	dc.w	          -12274 
	dc.w	          -12140 
	dc.w	          -12004 
	dc.w	          -11867 
	dc.w	          -11727 
	dc.w	          -11586 
	dc.w	          -11443 
	dc.w	          -11298 
	dc.w	          -11151 
	dc.w	          -11003 
	dc.w	          -10854 
	dc.w	          -10702 
	dc.w	          -10549 
	dc.w	          -10394 
	dc.w	          -10238 
	dc.w	          -10080 
	dc.w	          -9921 
	dc.w	          -9760 
	dc.w	          -9598 
	dc.w	          -9435 
	dc.w	          -9269 
	dc.w	          -9103 
	dc.w	          -8935 
	dc.w	          -8766 
	dc.w	          -8595 
	dc.w	          -8424 
	dc.w	          -8250 
	dc.w	          -8076 
	dc.w	          -7901 
	dc.w	          -7724 
	dc.w	          -7546 
	dc.w	          -7367 
	dc.w	          -7187 
	dc.w	          -7006 
	dc.w	          -6823 
	dc.w	          -6640 
	dc.w	          -6456 
	dc.w	          -6270 
	dc.w	          -6084 
	dc.w	          -5897 
	dc.w	          -5709 
	dc.w	          -5520 
	dc.w	          -5330 
	dc.w	          -5140 
	dc.w	          -4949 
	dc.w	          -4757 
	dc.w	          -4564 
	dc.w	          -4370 
	dc.w	          -4176 
	dc.w	          -3981 
	dc.w	          -3786 
	dc.w	          -3590 
	dc.w	          -3394 
	dc.w	          -3197 
	dc.w	          -2999 
	dc.w	          -2802 
	dc.w	          -2603 
	dc.w	          -2405 
	dc.w	          -2205 
	dc.w	          -2006 
	dc.w	          -1806 
	dc.w	          -1606 
	dc.w	          -1406 
	dc.w	          -1206 
	dc.w	          -1005 
	dc.w	          -804 
	dc.w	          -604 
	dc.w	          -403 
	dc.w	          -202 
Cos_Table:
	dc.w	           16384 
	dc.w	           16382 
	dc.w	           16379 
	dc.w	           16372 
	dc.w	           16364 
	dc.w	           16353 
	dc.w	           16339 
	dc.w	           16323 
	dc.w	           16305 
	dc.w	           16284 
	dc.w	           16260 
	dc.w	           16234 
	dc.w	           16206 
	dc.w	           16175 
	dc.w	           16142 
	dc.w	           16107 
	dc.w	           16069 
	dc.w	           16028 
	dc.w	           15985 
	dc.w	           15940 
	dc.w	           15892 
	dc.w	           15842 
	dc.w	           15790 
	dc.w	           15735 
	dc.w	           15678 
	dc.w	           15618 
	dc.w	           15557 
	dc.w	           15492 
	dc.w	           15426 
	dc.w	           15357 
	dc.w	           15286 
	dc.w	           15212 
	dc.w	           15136 
	dc.w	           15058 
	dc.w	           14978 
	dc.w	           14895 
	dc.w	           14810 
	dc.w	           14723 
	dc.w	           14634 
	dc.w	           14543 
	dc.w	           14449 
	dc.w	           14353 
	dc.w	           14255 
	dc.w	           14155 
	dc.w	           14053 
	dc.w	           13948 
	dc.w	           13842 
	dc.w	           13733 
	dc.w	           13622 
	dc.w	           13510 
	dc.w	           13395 
	dc.w	           13278 
	dc.w	           13159 
	dc.w	           13038 
	dc.w	           12916 
	dc.w	           12791 
	dc.w	           12665 
	dc.w	           12536 
	dc.w	           12406 
	dc.w	           12273 
	dc.w	           12139 
	dc.w	           12003 
	dc.w	           11866 
	dc.w	           11726 
	dc.w	           11585 
	dc.w	           11442 
	dc.w	           11297 
	dc.w	           11150 
	dc.w	           11002 
	dc.w	           10853 
	dc.w	           10701 
	dc.w	           10548 
	dc.w	           10393 
	dc.w	           10237 
	dc.w	           10079 
	dc.w	           9920 
	dc.w	           9759 
	dc.w	           9597 
	dc.w	           9434 
	dc.w	           9268 
	dc.w	           9102 
	dc.w	           8934 
	dc.w	           8765 
	dc.w	           8594 
	dc.w	           8423 
	dc.w	           8249 
	dc.w	           8075 
	dc.w	           7900 
	dc.w	           7723 
	dc.w	           7545 
	dc.w	           7366 
	dc.w	           7186 
	dc.w	           7005 
	dc.w	           6822 
	dc.w	           6639 
	dc.w	           6455 
	dc.w	           6269 
	dc.w	           6083 
	dc.w	           5896 
	dc.w	           5708 
	dc.w	           5519 
	dc.w	           5329 
	dc.w	           5139 
	dc.w	           4948 
	dc.w	           4756 
	dc.w	           4563 
	dc.w	           4369 
	dc.w	           4175 
	dc.w	           3980 
	dc.w	           3785 
	dc.w	           3589 
	dc.w	           3393 
	dc.w	           3196 
	dc.w	           2998 
	dc.w	           2801 
	dc.w	           2602 
	dc.w	           2404 
	dc.w	           2204 
	dc.w	           2005 
	dc.w	           1805 
	dc.w	           1605 
	dc.w	           1405 
	dc.w	           1205 
	dc.w	           1004 
	dc.w	           803 
	dc.w	           603 
	dc.w	           402 
	dc.w	           201 
	dc.w	          -1 
	dc.w	          -202 
	dc.w	          -403 
	dc.w	          -604 
	dc.w	          -804 
	dc.w	          -1005 
	dc.w	          -1206 
	dc.w	          -1406 
	dc.w	          -1606 
	dc.w	          -1806 
	dc.w	          -2006 
	dc.w	          -2205 
	dc.w	          -2405 
	dc.w	          -2603 
	dc.w	          -2802 
	dc.w	          -2999 
	dc.w	          -3197 
	dc.w	          -3394 
	dc.w	          -3590 
	dc.w	          -3786 
	dc.w	          -3981 
	dc.w	          -4176 
	dc.w	          -4370 
	dc.w	          -4564 
	dc.w	          -4757 
	dc.w	          -4949 
	dc.w	          -5140 
	dc.w	          -5330 
	dc.w	          -5520 
	dc.w	          -5709 
	dc.w	          -5897 
	dc.w	          -6084 
	dc.w	          -6270 
	dc.w	          -6456 
	dc.w	          -6640 
	dc.w	          -6823 
	dc.w	          -7006 
	dc.w	          -7187 
	dc.w	          -7367 
	dc.w	          -7546 
	dc.w	          -7724 
	dc.w	          -7901 
	dc.w	          -8076 
	dc.w	          -8250 
	dc.w	          -8424 
	dc.w	          -8595 
	dc.w	          -8766 
	dc.w	          -8935 
	dc.w	          -9103 
	dc.w	          -9269 
	dc.w	          -9435 
	dc.w	          -9598 
	dc.w	          -9760 
	dc.w	          -9921 
	dc.w	          -10080 
	dc.w	          -10238 
	dc.w	          -10394 
	dc.w	          -10549 
	dc.w	          -10702 
	dc.w	          -10854 
	dc.w	          -11003 
	dc.w	          -11151 
	dc.w	          -11298 
	dc.w	          -11443 
	dc.w	          -11586 
	dc.w	          -11727 
	dc.w	          -11867 
	dc.w	          -12004 
	dc.w	          -12140 
	dc.w	          -12274 
	dc.w	          -12407 
	dc.w	          -12537 
	dc.w	          -12666 
	dc.w	          -12792 
	dc.w	          -12917 
	dc.w	          -13039 
	dc.w	          -13160 
	dc.w	          -13279 
	dc.w	          -13396 
	dc.w	          -13511 
	dc.w	          -13623 
	dc.w	          -13734 
	dc.w	          -13843 
	dc.w	          -13949 
	dc.w	          -14054 
	dc.w	          -14156 
	dc.w	          -14256 
	dc.w	          -14354 
	dc.w	          -14450 
	dc.w	          -14544 
	dc.w	          -14635 
	dc.w	          -14724 
	dc.w	          -14811 
	dc.w	          -14896 
	dc.w	          -14979 
	dc.w	          -15059 
	dc.w	          -15137 
	dc.w	          -15213 
	dc.w	          -15287 
	dc.w	          -15358 
	dc.w	          -15427 
	dc.w	          -15493 
	dc.w	          -15558 
	dc.w	          -15619 
	dc.w	          -15679 
	dc.w	          -15736 
	dc.w	          -15791 
	dc.w	          -15843 
	dc.w	          -15893 
	dc.w	          -15941 
	dc.w	          -15986 
	dc.w	          -16029 
	dc.w	          -16070 
	dc.w	          -16108 
	dc.w	          -16143 
	dc.w	          -16176 
	dc.w	          -16207 
	dc.w	          -16235 
	dc.w	          -16261 
	dc.w	          -16285 
	dc.w	          -16306 
	dc.w	          -16324 
	dc.w	          -16340 
	dc.w	          -16354 
	dc.w	          -16365 
	dc.w	          -16373 
	dc.w	          -16380 
	dc.w	          -16383 
	dc.w	          -16384 
	dc.w	          -16383 
	dc.w	          -16380 
	dc.w	          -16373 
	dc.w	          -16365 
	dc.w	          -16354 
	dc.w	          -16340 
	dc.w	          -16324 
	dc.w	          -16306 
	dc.w	          -16285 
	dc.w	          -16261 
	dc.w	          -16235 
	dc.w	          -16207 
	dc.w	          -16176 
	dc.w	          -16143 
	dc.w	          -16108 
	dc.w	          -16070 
	dc.w	          -16029 
	dc.w	          -15986 
	dc.w	          -15941 
	dc.w	          -15893 
	dc.w	          -15843 
	dc.w	          -15791 
	dc.w	          -15736 
	dc.w	          -15679 
	dc.w	          -15619 
	dc.w	          -15558 
	dc.w	          -15493 
	dc.w	          -15427 
	dc.w	          -15358 
	dc.w	          -15287 
	dc.w	          -15213 
	dc.w	          -15137 
	dc.w	          -15059 
	dc.w	          -14979 
	dc.w	          -14896 
	dc.w	          -14811 
	dc.w	          -14724 
	dc.w	          -14635 
	dc.w	          -14544 
	dc.w	          -14450 
	dc.w	          -14354 
	dc.w	          -14256 
	dc.w	          -14156 
	dc.w	          -14054 
	dc.w	          -13949 
	dc.w	          -13843 
	dc.w	          -13734 
	dc.w	          -13623 
	dc.w	          -13511 
	dc.w	          -13396 
	dc.w	          -13279 
	dc.w	          -13160 
	dc.w	          -13039 
	dc.w	          -12917 
	dc.w	          -12792 
	dc.w	          -12666 
	dc.w	          -12537 
	dc.w	          -12407 
	dc.w	          -12274 
	dc.w	          -12140 
	dc.w	          -12004 
	dc.w	          -11867 
	dc.w	          -11727 
	dc.w	          -11586 
	dc.w	          -11443 
	dc.w	          -11298 
	dc.w	          -11151 
	dc.w	          -11003 
	dc.w	          -10854 
	dc.w	          -10702 
	dc.w	          -10549 
	dc.w	          -10394 
	dc.w	          -10238 
	dc.w	          -10080 
	dc.w	          -9921 
	dc.w	          -9760 
	dc.w	          -9598 
	dc.w	          -9435 
	dc.w	          -9269 
	dc.w	          -9103 
	dc.w	          -8935 
	dc.w	          -8766 
	dc.w	          -8595 
	dc.w	          -8424 
	dc.w	          -8250 
	dc.w	          -8076 
	dc.w	          -7901 
	dc.w	          -7724 
	dc.w	          -7546 
	dc.w	          -7367 
	dc.w	          -7187 
	dc.w	          -7006 
	dc.w	          -6823 
	dc.w	          -6640 
	dc.w	          -6456 
	dc.w	          -6270 
	dc.w	          -6084 
	dc.w	          -5897 
	dc.w	          -5709 
	dc.w	          -5520 
	dc.w	          -5330 
	dc.w	          -5140 
	dc.w	          -4949 
	dc.w	          -4757 
	dc.w	          -4564 
	dc.w	          -4370 
	dc.w	          -4176 
	dc.w	          -3981 
	dc.w	          -3786 
	dc.w	          -3590 
	dc.w	          -3394 
	dc.w	          -3197 
	dc.w	          -2999 
	dc.w	          -2802 
	dc.w	          -2603 
	dc.w	          -2405 
	dc.w	          -2205 
	dc.w	          -2006 
	dc.w	          -1806 
	dc.w	          -1606 
	dc.w	          -1406 
	dc.w	          -1206 
	dc.w	          -1005 
	dc.w	          -804 
	dc.w	          -604 
	dc.w	          -403 
	dc.w	          -202 
	dc.w	          -1 
	dc.w	           201 
	dc.w	           402 
	dc.w	           603 
	dc.w	           803 
	dc.w	           1004 
	dc.w	           1205 
	dc.w	           1405 
	dc.w	           1605 
	dc.w	           1805 
	dc.w	           2005 
	dc.w	           2204 
	dc.w	           2404 
	dc.w	           2602 
	dc.w	           2801 
	dc.w	           2998 
	dc.w	           3196 
	dc.w	           3393 
	dc.w	           3589 
	dc.w	           3785 
	dc.w	           3980 
	dc.w	           4175 
	dc.w	           4369 
	dc.w	           4563 
	dc.w	           4756 
	dc.w	           4948 
	dc.w	           5139 
	dc.w	           5329 
	dc.w	           5519 
	dc.w	           5708 
	dc.w	           5896 
	dc.w	           6083 
	dc.w	           6269 
	dc.w	           6455 
	dc.w	           6639 
	dc.w	           6822 
	dc.w	           7005 
	dc.w	           7186 
	dc.w	           7366 
	dc.w	           7545 
	dc.w	           7723 
	dc.w	           7900 
	dc.w	           8075 
	dc.w	           8249 
	dc.w	           8423 
	dc.w	           8594 
	dc.w	           8765 
	dc.w	           8934 
	dc.w	           9102 
	dc.w	           9268 
	dc.w	           9434 
	dc.w	           9597 
	dc.w	           9759 
	dc.w	           9920 
	dc.w	           10079 
	dc.w	           10237 
	dc.w	           10393 
	dc.w	           10548 
	dc.w	           10701 
	dc.w	           10853 
	dc.w	           11002 
	dc.w	           11150 
	dc.w	           11297 
	dc.w	           11442 
	dc.w	           11585 
	dc.w	           11726 
	dc.w	           11866 
	dc.w	           12003 
	dc.w	           12139 
	dc.w	           12273 
	dc.w	           12406 
	dc.w	           12536 
	dc.w	           12665 
	dc.w	           12791 
	dc.w	           12916 
	dc.w	           13038 
	dc.w	           13159 
	dc.w	           13278 
	dc.w	           13395 
	dc.w	           13510 
	dc.w	           13622 
	dc.w	           13733 
	dc.w	           13842 
	dc.w	           13948 
	dc.w	           14053 
	dc.w	           14155 
	dc.w	           14255 
	dc.w	           14353 
	dc.w	           14449 
	dc.w	           14543 
	dc.w	           14634 
	dc.w	           14723 
	dc.w	           14810 
	dc.w	           14895 
	dc.w	           14978 
	dc.w	           15058 
	dc.w	           15136 
	dc.w	           15212 
	dc.w	           15286 
	dc.w	           15357 
	dc.w	           15426 
	dc.w	           15492 
	dc.w	           15557 
	dc.w	           15618 
	dc.w	           15678 
	dc.w	           15735 
	dc.w	           15790 
	dc.w	           15842 
	dc.w	           15892 
	dc.w	           15940 
	dc.w	           15985 
	dc.w	           16028 
	dc.w	           16069 
	dc.w	           16107 
	dc.w	           16142 
	dc.w	           16175 
	dc.w	           16206 
	dc.w	           16234 
	dc.w	           16260 
	dc.w	           16284 
	dc.w	           16305 
	dc.w	           16323 
	dc.w	           16339 
	dc.w	           16353 
	dc.w	           16364 
	dc.w	           16372 
	dc.w	           16379 
	dc.w	           16382 

